# CreateOrganizationSettingDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**models** | **object** |  | [optional] 
**min_claim_date** | **datetime** |  | [optional] 
**max_claim_date** | **datetime** |  | [optional] 
**max_cohort_windows** | **float** |  | 
**pipeline_version** | **str** |  | [optional] 
**risk_version** | **str** |  | [optional] 
**impactability_version** | **str** |  | [optional] 
**primary_database** | **str** |  | [optional] 
**features_database** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

